package components;

//add imports
import cli.TraceLabSDK.*;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Scanner;
import java.util.logging.Level;
import java.util.logging.Logger;

@ComponentAttribute.Annotation(
        Name = "CSV_Rows",
        Description = "Read in row-separated data from a csv file.",
        Author = "sarah",
        Version = "1.0",
        ConfigurationType = config.class)
@IOSpecAttribute.Annotation.__Multiple({
    @IOSpecAttribute.Annotation(IOType = IOSpecType.__Enum.Output, Name = "contents",
            DataType = ArrayList.class, Description = "Optional description for the tooltip")
})
public class CSV_Rows extends BaseComponent {

    private final config configFile;

    public CSV_Rows(ComponentLogger log) {
        super(log);
        configFile = new config();
        super.set_Configuration(configFile);
    }

    @Override
    public void Compute() {
        super.get_Logger().Trace("CSV_Rows worked!");

        //create a string for the input file
        String in_fileName = configFile.getInputFile();

        //create an ArrayList of ArrayLists to store the output of CsvReader()
        ArrayList<ArrayList<String>> output = null;
        
        //store the output of CsvReader() in output
        try {
            output = CsvReader(in_fileName);
        } catch (IOException ex) {
            Logger.getLogger(CSV_Rows.class.getName()).log(Level.SEVERE, null, ex);
        }

        //store the output of CsvReader() in the workspace
        super.get_Workspace().Store("contents", output);
    }

    //declare global variables
    static String data;
    static String trash;
    static int count = 0;

    /**
     * @param inputFile
     * @return
     * @throws java.io.FileNotFoundException
     */
    public static ArrayList<ArrayList<String>> CsvReader(String inputFile) throws FileNotFoundException, IOException {

        //create an ArrayList to hold all the data
        ArrayList<ArrayList<String>> csvData = new ArrayList<>();
        try (Scanner new_scanner = new Scanner(new File(inputFile))) {
            System.out.println();

            //declare delimiter
            new_scanner.useDelimiter("\\D");

            //while there is another line...
            while (new_scanner.hasNextLine()) {
                //if it is not the first line, collect the "\n" at the end of each line
                if (count > 0) {
                    trash = new_scanner.nextLine();
                } // END, if

                //get the next line
                data = new_scanner.nextLine();

                //create another ArrayList to store the row of data
                ArrayList<String> csvRow = new ArrayList<>();

                //while there is another element in the row, add the element to csvRow
                while (new_scanner.hasNext()) {
                    csvRow.add(new_scanner.next());
                }

                //add the csvRow ArrayList to the csvData ArrayList
                csvData.add(csvRow);
            } // END, while
        } // END, try
        //return the csvData ArrayList so it can be used
        return csvData;
    } // END, CsvReader()
} // END, class
